@@ -9,6 +9,7 @@
 #include "mainwindow.h"
 #include "mainwidget.h"
 #include "settings.h"
+#include "whatsnew/whatsnewtranslations.h"
 #include <KAboutData>
 #include <KActionCollection>
 #include <KConfigGroup>
@@ -20,6 +21,7 @@
 #include <KStandardAction>
 #include <KToggleFullScreenAction>
 #include <KToolBar>
+#include <PimCommon/WhatsNewMessageWidget>
 #include <QAction>
 #include <QFontDatabase>
 #include <QMenuBar>
@@ -73,8 +75,22 @@ MainWindow::MainWindow()
             needUpdateVersionWidget->setObsoleteVersion(status);
         }
     }
-    mainWidgetLayout->addWidget(mMainWidget);
 
+    WhatsNewTranslations translations;
+    const QString newFeaturesMD5 = translations.newFeaturesMD5();
+    if (!newFeaturesMD5.isEmpty()) {
+        const bool hasNewFeature = (Settings::self()->previousNewFeaturesMD5() != newFeaturesMD5);
+        if (hasNewFeature) {
+            auto whatsNewMessageWidget = new PimCommon::WhatsNewMessageWidget(this);
+            whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
+            whatsNewMessageWidget->setObjectName(QStringLiteral("whatsNewMessageWidget"));
+            mainWidgetLayout->addWidget(whatsNewMessageWidget);
+            Settings::self()->setPreviousNewFeaturesMD5(newFeaturesMD5);
+            whatsNewMessageWidget->animatedShow();
+        }
+    }
+
+    mainWidgetLayout->addWidget(mMainWidget);
     setCentralWidget(mainWidget);
 
     setStandardToolBarMenuEnabled(true);
@@ -103,15 +119,15 @@ MainWidget *MainWindow::mainWidget() const
 
 void MainWindow::initActions()
 {
-    KStandardAction::quit(this, &MainWindow::close, actionCollection());
+    KStandardActions::quit(this, &MainWindow::close, actionCollection());
     mShowMenuBarAction = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actionCollection());
 
-    QAction *action = KStandardAction::keyBindings(this, &MainWindow::configureKeyBindings, actionCollection());
+    QAction *action = KStandardActions::keyBindings(this, &MainWindow::configureKeyBindings, actionCollection());
     action->setWhatsThis(i18nc("@info:whatsthis",
                                "You will be presented with a dialog where you can configure "
                                "the application-wide shortcuts."));
-    KStandardAction::configureToolbars(this, &MainWindow::configureToolbars, actionCollection());
-    KStandardAction::preferences(this, &MainWindow::configure, actionCollection());
+    KStandardActions::configureToolbars(this, &MainWindow::configureToolbars, actionCollection());
+    KStandardActions::preferences(this, &MainWindow::configure, actionCollection());
     if (menuBar()) {
         mHamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, actionCollection());
         mHamburgerMenu->setShowMenuBarAction(mShowMenuBarAction);
@@ -210,7 +226,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
                                          i18n("<qt>This will hide the menu bar completely."
                                               " You can show it again by typing %1.</qt>",
                                               accel),
-                                         i18n("Hide menu bar"),
+                                         i18nc("@title:window", "Hide menu bar"),
                                          QStringLiteral("HideMenuBarWarning"));
             }
             menuBar()->hide();
